//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Mask/PointItem.cpp
//! @brief     Implements class PointItem.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Mask/PointItem.h"
#include "GUI/Model/Util/Backup.h"
#include "GUI/Model/Util/UtilXML.h"
#include <QRegularExpression>

PointItem::PointItem()
{
    m_posX.init("x", "x coordinate", 0, 4, RealLimits::limitless(), "xPos");
    m_posY.init("y", "y coordinate", 0, 4, RealLimits::limitless(), "yPos");
}

void PointItem::setPosX(double val)
{
    m_posX.setValue(val);
}
void PointItem::setPosY(double val)
{
    m_posY.setValue(val);
}

void PointItem::writeTo(QXmlStreamWriter* w) const
{
    XML::writeAttribute(w, XML::Attrib::xPos, posX().value());
    XML::writeAttribute(w, XML::Attrib::yPos, posY().value());
    XML::writeAttribute(w, XML::Attrib::version, uint(1));
}

void PointItem::readFrom(QXmlStreamReader* r)
{
    const uint version = XML::readUInt(r, XML::Attrib::version);
    Q_UNUSED(version)

    setPosX(XML::readDouble(r, XML::Attrib::xPos));
    setPosY(XML::readDouble(r, XML::Attrib::yPos));
}
